package com.emato.cus.supervise.biz.acq0402back;

import com.emato.cus.supervise.biz.CusWmsTask;
import com.emato.cus.supervise.constant.EmtRecordTimeEnum;
import com.emato.cus.supervise.domain.WmsAcqShelfLoad04;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 货物上下架数据 退港 业务
 * @author Scott Chen
 * @version 1.0
 * 2017-10-28 13:35
 */
@Service
public class AcqShelfLoadBackBiz04 implements CusWmsTask {
    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadBackBiz04.class);

    @Autowired
    private Acq0402RecordTime acq0402RecordTime;

    @Autowired
    private Acq0402WmsData acq0402WmsData;

    @Autowired
    private Acq0402CusData acq0402CusData;

    private static final String DATA_TYPE_INFO = "[" + EmtRecordTimeEnum.I_01_02.getCode() + "]" + EmtRecordTimeEnum.I_01_02.getName();


    /**
     * 任务入口
     */
    @Override
    public void task() {

        // 获取扫描时间
        String oldThisTime = acq0402RecordTime.getEmtRecordTime();
        if (StringUtils.isBlank(oldThisTime)) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】未获取到本次扫描时间, 本次扫描提前结束！！！");
            //下次扫描时间
            acq0402RecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN),
                    LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN));
            return;

        }

        // 扫描WMS 数据
        List<WmsAcqShelfLoad04> wmsList = acq0402WmsData.getWmsData(oldThisTime);
        if (wmsList == null || wmsList.size() == 0) {
            logger.info("--- 【" + DATA_TYPE_INFO + "】获取到本次扫描数据为空, 不执行写数据操作, 本次扫描提前结束！！！");
            //下次扫描时间
            acq0402RecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN), oldThisTime);
            return;
        }

        // 写CUS 数据
        int res = acq0402CusData.insertCus(wmsList);

        // 更新扫描时间
        boolean bl = acq0402RecordTime.updateWmsRecordTime(LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN), oldThisTime);

    }

}
