package com.emato.cus.supervise.schedule;

import com.emato.cus.supervise.biz.acq0401up.AcqShelfLoadUpBiz04;
import com.emato.cus.supervise.biz.acq0402back.AcqShelfLoadBackBiz04;
import com.emato.cus.supervise.biz.acq0403out.AcqShelfLoadOutBiz04;
import com.emato.cus.supervise.util.LocalDateTimeUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

/**
 * 货物上下架数据 计划任务
 *
 * @author Scott Chen
 * @version 1.0
 * 2017-10-28 11:42
 */
@Configuration
@EnableScheduling
public class AcqShelfLoadSchedule04 {
    private static final Logger logger = LoggerFactory.getLogger(AcqShelfLoadSchedule04.class);

    @Autowired
    private AcqShelfLoadUpBiz04 acqShelfLoadUpBiz04;

    @Autowired
    private AcqShelfLoadBackBiz04 acqShelfLoadBackBiz04;

    @Autowired
    private AcqShelfLoadOutBiz04 acqShelfLoadOutBiz04;

    /**
     * 上架
     */
    //每月1号开始,每天10,18点执行各1次,共2次
    //@Scheduled(cron = "0 0 10,18 1/1 * ?")
    @Scheduled(cron = "0 0/10 * * * ?")
    public void timerUp() {
        logger.info("==================== 货物上下架数据::上架::监控数据读取开始 ====================");
        String begDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务开始时间: {}", begDateTime);

        acqShelfLoadUpBiz04.task();


        String endDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务结束时间: {}", endDateTime);
        logger.info("==================== 货物上下架数据::上架::监控数据读取结束 ====================");

    }

    /**
     * 退港
     */
    //每月1号开始,每天18点执行1次,共1次
    //@Scheduled(cron = "0 0 18 1/1 * ?")
    @Scheduled(cron = "0 0/10 * * * ?")
    public void timerBack() {
        logger.info("==================== 货物上下架数据::退港::监控数据读取开始 ====================");
        String begDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务开始时间: {}", begDateTime);

        acqShelfLoadBackBiz04.task();


        String endDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务结束时间: {}", endDateTime);
        logger.info("==================== 货物上下架数据::退港::监控数据读取结束 ====================");

    }

    /**
     * 正常拣货
     */
    //@Scheduled(cron = "0 0/1 * * * ?")
    //每月1号开始,每天10,12,15,18,22点各1次,共5次
    //@Scheduled(cron = "0 0 10,12,15,18,22 1/1 * ?")
    @Scheduled(cron = "0 0/10 * * * ?")
    public void timerOut() {
        logger.info("==================== 货物上下架数据::正常拣货::监控数据读取开始 ====================");
        String begDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务开始时间: {}", begDateTime);

        acqShelfLoadOutBiz04.task();


        String endDateTime = LocalDateTimeUtils.formatNow(LocalDateTimeUtils.DATA_TIME_HYPHEN);
        logger.info("--- 任务结束时间: {}", endDateTime);
        logger.info("==================== 货物上下架数据::正常拣货::监控数据读取结束 ====================");

    }

}
